package main

import (
	"fmt"
	"zoho/pkg/reportclient"
	
)

var(
	email = "user@zoho.com"
	dbname = "<dbname>"
	tbname = "<tablename>"
	authtoken = "<authtoken>"
	dbid = "<dbid>"
	objid = "<objid>"
	dbkey = "<dbkey>"
)

func addrow() {
	url := reportclient.GetUri(email, dbname, tbname)
	columnvalues := map[string]string{}
	columnvalues["Id"] = "999"
	columnvalues["Name"] = "zzz"
	columnvalues["Salary"] = "999"
	columnvalues["Experience"] = "999"
	resultmap , err := reportclient.AddRow(url, columnvalues)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(resultmap)
	}
}

func deletedata() {
	url := reportclient.GetUri(email, dbname, tbname)
	params := map[string]string{}
	params["ZOHO_CRITERIA"] = "\"Name\"='a'"
	err := reportclient.DeleteData(url, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func updatedata() {
	url := reportclient.GetUri(email, dbname, tbname)
	params := map[string]string{}
	params["Salary"] = "100"
	params["ZOHO_CRITERIA"] = "Salary=10"
	err := reportclient.UpdateData(url, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func importdata() {
	url := reportclient.GetUri(email, dbname, tbname)
	params := map[string]string{}
	file := "filepath"
	importtype := "APPEND"
	autoidentity := "true"
	onerror := "ABORT"
	resp , err := reportclient.ImportData(url, file, importtype, autoidentity, onerror, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(resp.ImportErrors)
		fmt.Println(resp.ColumnDetails)
		fmt.Println(resp.ImportType)
		fmt.Println(resp.Warnings)
		fmt.Println(resp.SelectedColumnCount)
		fmt.Println(resp.SuccessRowCount)
		fmt.Println(resp.ImportOperation)
		fmt.Println(resp.TotalColumnCount)
		fmt.Println(resp.TotalRowCount)
	}
}

func exportdata() {
	url := reportclient.GetUri(email, dbname, tbname)
	outputformat := "html"
	filename := "zoho"
	params := map[string]string{}
	err := reportclient.ExportData(url, filename, outputformat, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func createtable() {
	url := reportclient.GetDbUri(email, dbname)
	tableconfig := "{\"TABLENAME\": \"SystemTable\",\"TABLEDESCRIPTION\": \"Testing Purpose\",\"SYSTEMTABLE\": true,\"FOLDERNAME\": \"NewFolder\",\"COLUMNS\":[{\"COLUMNNAME\": \"Product Category\",\"DATATYPE\": \"PLAIN\",\"DEFAULT\": \"Test\",\"MANDATORY\" :  \"Yes\",\"DESCRIPTION\" : \"Testing2\"}]}"
	err := reportclient.CreateTable(url, tableconfig)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func addcolumn() {
	url := reportclient.GetUri(email, dbname, tbname)
	columnname := "Newcolumn"
	datatype := "PLAIN"
	err := reportclient.AddColumn(url, columnname, datatype)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func deletecolumn() {
	url := reportclient.GetUri(email, dbname, tbname)
	columnname := "Oldcolumn"
	err := reportclient.DeleteColumn(url, columnname)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func renamecolumn() {
	url := reportclient.GetUri(email, dbname, tbname)
	oldcolumnname := "oldcolumn"
	newcolumnname := "newcolumn"
	err := reportclient.RenameColumn(url, oldcolumnname, newcolumnname)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func copydatabase() {
	url := reportclient.GetDbUri(email, dbname)
	newdbname := "NewDB"
	params := map[string]string{}
	newid , err := reportclient.CopyDatabase(url, newdbname, dbkey, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(newid)
	}
}

func deletedatabase() {
	url := reportclient.GetUserUri(email)
	dbname := "OldDB"
	err := reportclient.DeleteDatabase(url, dbname)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func addlookup() {
	url := reportclient.GetUri(email, dbname, tbname)
	columnname := "total"
	refertable := "New"
	refercolumn := "parenttotal"
	onerror := "ABORT"
	err := reportclient.AddLookup(url, columnname, refertable, refercolumn, onerror)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func removelookup() {
	url := reportclient.GetUri(email, dbname, tbname)
	columnname := "total"
	err := reportclient.RemoveLookup(url, columnname)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func copyreports() {
	url := reportclient.GetDbUri(email, dbname)
	viewnames := "Sampleview"
	destdbname := "NewSample"
	err := reportclient.CopyReports(url, viewnames, destdbname, dbkey)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func copyformula() {
	url := reportclient.GetUri(email, dbname, tbname)
	formulaname := "total"
	destdbname := "sample"
	err := reportclient.CopyFormula(url, formulaname, destdbname, dbkey)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func renameview() {
	url := reportclient.GetDbUri(email, dbname)
	viewname := "Datalist"
	newname := "Newview"
	newdesc := ""
	err := reportclient.RenameView(url, viewname, newname, newdesc)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func databasemetadata() {
	url := reportclient.GetUserUri(email)
	metadata := "ZOHO_CATALOG_LIST"
	data , err := reportclient.GetDatabaseMetadata(url, metadata)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(data)
	}
}

func getdatabasename() {
	url := reportclient.GetUserUri(email)
	databasename , err := reportclient.GetDatabaseName(url, dbid)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(databasename)
	}
}

func getviewname() {
	url := reportclient.GetUserUri(email)
	viewname , err := reportclient.GetViewname(url, objid)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(viewname)
	}
}

func getinfo() {
	url := reportclient.GetUri(email, dbname, tbname)
	info , err := reportclient.GetInfo(url)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(info)
	}
}

func shareview() {
	url := reportclient.GetDbUri(email, dbname)
	emailids := "user@zoho.com"
	views := "views"
	params := map[string]string{}
	params["ZOHO_READ"] = "true"
	err := reportclient.ShareView(url, emailids, views, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func removeshare() {
	url := reportclient.GetDbUri(email, dbname)
	emailids := "user@zoho.com"
	params := map[string]string{}
	params["ZOHO_ALLVIEWS"] = "true"
	err := reportclient.RemoveShare(url, emailids, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func adddbowner() {
	url := reportclient.GetDbUri(email, dbname)
	emailids := "user@zoho.com"
	params := map[string]string{}
	err := reportclient.AddDbOwner(url, emailids, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func removedbowner() {
	url := reportclient.GetDbUri(email, dbname)
	emailids := "user@zoho.com"
	params := map[string]string{}
	err := reportclient.RemoveDbOwner(url, emailids, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func getviewurl() {
	url := reportclient.GetUri(email, dbname, tbname)
	viewurl , err := reportclient.GetViewUrl(url)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(viewurl)
	}

}

func getembedurl() {
	url := reportclient.GetUri(email, dbname, tbname)
	params := map[string]string{}
	embedurl , err := reportclient.GetEmbedUrl(url, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(embedurl)
	}
}

func adduser() {
	url := reportclient.GetUserUri(email)
	emailids := "user@zoho.com"
	err := reportclient.AddUser(url, emailids)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func removeuser() {
	url := reportclient.GetUserUri(email)
	emailids := "user@zoho.com"
	err := reportclient.RemoveUser(url, emailids)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func activateuser() {
	url := reportclient.GetUserUri(email)
	emailids := "user@zoho.com"
	err := reportclient.ActivateUser(url, emailids)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func deactivateuser() {
	url := reportclient.GetUserUri(email)
	emailids := "user@zoho.com"
	err := reportclient.DeActivateUser(url, emailids)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println("Success")
	}
}

func getshareinfo() {
	url := reportclient.GetDbUri(email, dbname)
	shareinfo , err := reportclient.GetShareInfo(url)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(shareinfo.GroupMembers)
		fmt.Println(shareinfo.UserInfo)
	}
}

func getplaninfo() {
	url := reportclient.GetUserUri(email)
	plan , err := reportclient.GetPlanInfo(url)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(plan.Plan)
	}
}

func getcopydbkey() {
	url := reportclient.GetDbUri(email, dbname)
	dbkey , err := reportclient.GetCopyDbKey(url)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(dbkey)
	}
}

func isdbexist(){
	url := reportclient.GetUserUri(email)
	databasename := "Employee1"
	params := map[string]string{}
	result , err := reportclient.IsDbExist(url, databasename, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(result)
	}
}

func getusers(){
	url := reportclient.GetUserUri(email)
	params := map[string]string{}
	result , err := reportclient.GetUsers(url, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(result)
	}
}

func autogenreports(){
	url := reportclient.GetUri(email, "Auto-Copy", "Auto")
	source := "COLUMN"
	params := map[string]string{}
	params["ZOHO_COLUMN_NAME"] = "Region"
	result , err := reportclient.AutoGenReports(url, source, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(result)
	}
}

func hidecolumn(){
	url := reportclient.GetUri(email, "Auto-Copy", "Auto")
	columnnames := []string{"Cost" , "Cost1" , "Sales"}
	params := map[string]string{}
	result , err := reportclient.HideColumn(url, columnnames, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(result)
	}
}

func showcolumn(){
	url := reportclient.GetUri(email, "Auto-Copy", "Auto")
	columnnames := []string{"Cost" , "Cost1" , "Sales"}
	params := map[string]string{}
	result , err := reportclient.ShowColumn(url, columnnames, params)
	if(err != nil){
		fmt.Println(err.ErrorMessage)
		fmt.Println(err.ErrorCode)
		fmt.Println(err.Action)
		fmt.Println(err.HttpStatusCode)
	}else{
		fmt.Println(result)
	}
}

func main() {
	reportclient.SetAuthToken(authtoken)
	getcopydbkey()
}
